Cointegration Tests
===================

.. module:: arch.unitroot.cointegration
   :synopsis: Cointegration tests and estimation

.. currentmodule:: arch.unitroot.cointegration

.. autosummary::
   :toctree: generated/

   engle_granger
   phillips_ouliaris

Cointegrating Vector Estimation
===============================
.. autosummary::
   :toctree: generated/

   DynamicOLS
   FullyModifiedOLS
   CanonicalCointegratingReg

Results Classes
---------------

.. autosummary::
   :toctree: generated/

   CointegrationAnalysisResults
   DynamicOLSResults
   EngleGrangerTestResults
   PhillipsOuliarisTestResults
